[GnomeMeeting-devel-list] [PATCH] "log" is used instead of "history" in non-"calls history" cases
- From: PUYDT Julien <julien puydt laposte net>
- To: GnomeMeeting Devel Liste <gnomemeeting-devel-list gnome org>
- Subject: [GnomeMeeting-devel-list] [PATCH] "log" is used instead of "history" in non-"calls history" cases
- Date: Sat, 24 Jan 2004 11:09:59 +0100
Hi,
this patch makes sure "history" is never used in a context where "log"
was meant, with the following remarks:
* I didn't change any user message, so no translation update should be
needed (the goal after all is to make the _source_ more readable);
* I did change the gconf key names, hence some cleaning will be needed
(I'm sure Damien will give us the exact command to run when the patch
will be in ;-) )
After this patch, I'll probably re-run through the sources: "history"
and "calls history" are used, perhaps "calls history" should be used
everywhere for consistance (but that is far less annoying than what this
patch fixes).
Snark
diff -ur gnomemeeting-cvs-20040124.CVS/gnomemeeting.schemas.in.in gnomemeeting-cvs-20040124.CVS.patched/gnomemeeting.schemas.in.in
--- gnomemeeting-cvs-20040124.CVS/gnomemeeting.schemas.in.in 2004-01-22 23:06:26.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/gnomemeeting.schemas.in.in 2004-01-24 09:56:14.000000000 +0100
@@ -742,14 +742,14 @@
</locale>
</schema>
<schema>
- <key>/schemas/apps/gnomemeeting/general/user_interface/general_history_window/position</key>
- <applyto>/apps/gnomemeeting/general/user_interface/general_history_window/position</applyto>
+ <key>/schemas/apps/gnomemeeting/general/user_interface/log_window/position</key>
+ <applyto>/apps/gnomemeeting/general/user_interface/log_window/position</applyto>
<owner>GnomeMeeting</owner>
<type>string</type>
<default>0,0</default>
<locale name="C">
- <short>Position on the screen of the general history window</short>
- <long>Position on the screen of the general history window</long>
+ <short>Position on the screen of the log window</short>
+ <long>Position on the screen of the log window</long>
</locale>
</schema>
<schema>
@@ -775,14 +775,14 @@
</locale>
</schema>
<schema>
- <key>/schemas/apps/gnomemeeting/general/user_interface/general_history_window/size</key>
- <applyto>/apps/gnomemeeting/general/user_interface/general_history_window/size</applyto>
+ <key>/schemas/apps/gnomemeeting/general/user_interface/log_window/size</key>
+ <applyto>/apps/gnomemeeting/general/user_interface/log_window/size</applyto>
<owner>GnomeMeeting</owner>
<type>string</type>
<default>330,225</default>
<locale name="C">
- <short>Size of the general history window</short>
- <long>Size of the general history window</long>
+ <short>Size of the log window</short>
+ <long>Size of the log window</long>
</locale>
</schema>
<schema>
diff -ur gnomemeeting-cvs-20040124.CVS/src/callbacks.cpp gnomemeeting-cvs-20040124.CVS.patched/src/callbacks.cpp
--- gnomemeeting-cvs-20040124.CVS/src/callbacks.cpp 2004-01-22 21:06:25.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/callbacks.cpp 2004-01-24 10:05:53.000000000 +0100
@@ -203,8 +203,8 @@
gchar *menu_suspend_msg = NULL;
gchar *menu_resume_msg = NULL;
- gchar *history_suspend_msg = NULL;
- gchar *history_resume_msg = NULL;
+ gchar *log_suspend_msg = NULL;
+ gchar *log_resume_msg = NULL;
gdk_threads_leave ();
@@ -235,8 +235,8 @@
menu_suspend_msg = g_strdup (_("Suspend _Audio"));
menu_resume_msg = g_strdup (_("Resume _Audio"));
- history_suspend_msg = g_strdup (_("Audio transmission: suspended"));
- history_resume_msg = g_strdup (_("Audio transmission: resumed"));
+ log_suspend_msg = g_strdup (_("Audio transmission: suspended"));
+ log_resume_msg = g_strdup (_("Audio transmission: resumed"));
gdk_threads_enter ();
b = GTK_TOGGLE_BUTTON (gw->audio_chan_button);
@@ -249,8 +249,8 @@
menu_suspend_msg = g_strdup (_("Suspend _Video"));
menu_resume_msg = g_strdup (_("Resume _Video"));
- history_suspend_msg = g_strdup (_("Video transmission: suspended"));
- history_resume_msg = g_strdup (_("Video transmission: resumed"));
+ log_suspend_msg = g_strdup (_("Video transmission: suspended"));
+ log_resume_msg = g_strdup (_("Video transmission: resumed"));
gdk_threads_enter ();
b = GTK_TOGGLE_BUTTON (gw->video_chan_button);
@@ -267,8 +267,8 @@
gtk_label_set_text_with_mnemonic (GTK_LABEL (child),
menu_suspend_msg);
- gnomemeeting_log_insert (history_resume_msg);
- gnomemeeting_statusbar_flash (gw->statusbar, history_resume_msg);
+ gnomemeeting_log_insert (log_resume_msg);
+ gnomemeeting_statusbar_flash (gw->statusbar, log_resume_msg);
g_signal_handlers_block_by_func (G_OBJECT (b),
(gpointer) pause_channel_callback,
@@ -289,8 +289,8 @@
gtk_label_set_text_with_mnemonic (GTK_LABEL (child),
menu_resume_msg);
- gnomemeeting_log_insert (history_suspend_msg);
- gnomemeeting_statusbar_flash (gw->statusbar, history_suspend_msg);
+ gnomemeeting_log_insert (log_suspend_msg);
+ gnomemeeting_statusbar_flash (gw->statusbar, log_suspend_msg);
g_signal_handlers_block_by_func (G_OBJECT (b),
(gpointer) pause_channel_callback,
@@ -308,8 +308,8 @@
g_free (menu_suspend_msg);
g_free (menu_resume_msg);
- g_free (history_suspend_msg);
- g_free (history_resume_msg);
+ g_free (log_suspend_msg);
+ g_free (log_resume_msg);
connection->Unlock ();
}
@@ -466,7 +466,7 @@
ep = GnomeMeeting::Process ()->Endpoint ();
gnomemeeting_window_hide (gm);
- gnomemeeting_window_hide (gw->history_window);
+ gnomemeeting_window_hide (gw->log_window);
gnomemeeting_window_hide (gw->calls_history_window);
gnomemeeting_window_hide (gw->ldap_window);
gnomemeeting_window_hide (gw->pref_window);
diff -ur gnomemeeting-cvs-20040124.CVS/src/common.h gnomemeeting-cvs-20040124.CVS.patched/src/common.h
--- gnomemeeting-cvs-20040124.CVS/src/common.h 2004-01-22 22:07:29.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/common.h 2004-01-24 09:36:17.000000000 +0100
@@ -203,8 +203,8 @@
GtkWidget *remote_name;
GtkWidget *splash_win;
GtkWidget *combo;
- GtkWidget *history_window;
- GtkWidget *history_text_view;
+ GtkWidget *log_window;
+ GtkWidget *log_text_view;
GtkWidget *main_notebook;
GtkWidget *main_video_image;
GtkWidget *local_video_image;
diff -ur gnomemeeting-cvs-20040124.CVS/src/endpoint.cpp gnomemeeting-cvs-20040124.CVS.patched/src/endpoint.cpp
--- gnomemeeting-cvs-20040124.CVS/src/endpoint.cpp 2004-01-22 23:06:27.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/endpoint.cpp 2004-01-24 10:09:12.000000000 +0100
@@ -721,7 +721,7 @@
GetRemoteConnectionInfo (connection, utf8_name, utf8_app, utf8_url);
- /* Update the history and status bar */
+ /* Update the log and status bar */
msg = g_strdup_printf (_("Call from %s"), (const char *) utf8_name);
gnomemeeting_threads_enter ();
gnomemeeting_statusbar_push (gw->statusbar, msg);
@@ -781,7 +781,7 @@
/* Take that action */
if (do_reject || do_forward || do_answer) {
- /* Add the full message in the history */
+ /* Add the full message in the log */
gnomemeeting_threads_enter ();
gnomemeeting_log_insert (msg);
gnomemeeting_threads_leave ();
diff -ur gnomemeeting-cvs-20040124.CVS/src/endpoint.h gnomemeeting-cvs-20040124.CVS.patched/src/endpoint.h
--- gnomemeeting-cvs-20040124.CVS/src/endpoint.h 2004-01-20 12:46:57.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/endpoint.h 2004-01-24 10:08:55.000000000 +0100
@@ -177,7 +177,7 @@
/* DESCRIPTION : This callback is called when a call is forwarded.
- * BEHAVIOR : Outputs a message in the history and statusbar.
+ * BEHAVIOR : Outputs a message in the log and statusbar.
* PRE : /
*/
virtual BOOL OnConnectionForwarded (H323Connection &,
diff -ur gnomemeeting-cvs-20040124.CVS/src/gnomemeeting.cpp gnomemeeting-cvs-20040124.CVS.patched/src/gnomemeeting.cpp
--- gnomemeeting-cvs-20040124.CVS/src/gnomemeeting.cpp 2004-01-22 21:06:25.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/gnomemeeting.cpp 2004-01-24 09:26:58.000000000 +0100
@@ -115,7 +115,7 @@
memset ((void *) rtp, 0, sizeof (struct _GmRtpData));
gw->docklet = gw->ldap_window = gw->pref_window = gw->calls_history_window =
- gw->splash_win = gw->incoming_call_popup = gw->history_window =
+ gw->splash_win = gw->incoming_call_popup = gw->log_window =
gw->audio_transmission_popup = gw->audio_reception_popup =
#ifndef DISABLE_GNOME
gw->druid_window =
@@ -149,8 +149,8 @@
if (gw->pref_window)
gtk_widget_destroy (gw->pref_window);
- if (gw->history_window)
- gtk_widget_destroy (gw->history_window);
+ if (gw->log_window)
+ gtk_widget_destroy (gw->log_window);
if (gw->calls_history_window)
gtk_widget_destroy (gw->calls_history_window);
if (gm)
@@ -437,7 +437,7 @@
/* Build the GUI */
gnomemeeting_stock_icons_init ();
gw->tips = gtk_tooltips_new ();
- gw->history_window = gnomemeeting_history_window_new ();
+ gw->log_window = gnomemeeting_log_window_new ();
gw->calls_history_window = gnomemeeting_calls_history_window_new (chw);
gw->pc_to_phone_window = gnomemeeting_pc_to_phone_window_new ();
gw->pref_window = gnomemeeting_pref_window_new (pw);
diff -ur gnomemeeting-cvs-20040124.CVS/src/lid.h gnomemeeting-cvs-20040124.CVS.patched/src/lid.h
--- gnomemeeting-cvs-20040124.CVS/src/lid.h 2004-01-20 12:46:58.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/lid.h 2004-01-24 09:23:08.000000000 +0100
@@ -120,7 +120,7 @@
/* DESCRIPTION : /
* BEHAVIOR : Opens the Line Interface Device with the options
* stored in the GConf database. Displays success messages
- * in the generic history and failure messages in popups.
+ * in the log and failure messages in popups.
* PRE : /
*/
BOOL Open ();
diff -ur gnomemeeting-cvs-20040124.CVS/src/menu.cpp gnomemeeting-cvs-20040124.CVS.patched/src/menu.cpp
--- gnomemeeting-cvs-20040124.CVS/src/menu.cpp 2004-01-20 12:46:58.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/menu.cpp 2004-01-24 09:22:36.000000000 +0100
@@ -478,11 +478,11 @@
GTK_MENU_SEPARATOR,
- GTK_MENU_ENTRY("general_history", _("General History"),
+ GTK_MENU_ENTRY("log", _("General History"),
_("View the operations history"),
NULL, 0,
GTK_SIGNAL_FUNC (show_window_cb),
- (gpointer) gw->history_window, TRUE),
+ (gpointer) gw->log_window, TRUE),
GTK_MENU_ENTRY("calls_history", _("Calls History"),
_("View the calls history"),
GM_STOCK_CALLS_HISTORY, 'h',
diff -ur gnomemeeting-cvs-20040124.CVS/src/sound_handling.h gnomemeeting-cvs-20040124.CVS.patched/src/sound_handling.h
--- gnomemeeting-cvs-20040124.CVS/src/sound_handling.h 2004-01-20 12:46:58.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/sound_handling.h 2004-01-24 09:21:48.000000000 +0100
@@ -57,7 +57,7 @@
/* DESCRIPTION : /
* BEHAVIOR : Puts ESD (and Artsd if support compiled in) into standby
* mode. An error message is displayed in the gnomemeeting
- * history if it failed. No message is displayed if it is
+ * log if it failed. No message is displayed if it is
* succesful.
* PRE : /
*/
@@ -67,7 +67,7 @@
/* DESCRIPTION : /
* BEHAVIOR : Puts ESD (and Artsd if support compiled in) into normal
* mode. An error message is displayed in the gnomemeeting
- * history if it failed. No message is displayed if it is
+ * log if it failed. No message is displayed if it is
* succesful.
* PRE : /
*/
diff -ur gnomemeeting-cvs-20040124.CVS/src/tools.cpp gnomemeeting-cvs-20040124.CVS.patched/src/tools.cpp
--- gnomemeeting-cvs-20040124.CVS/src/tools.cpp 2004-01-24 01:41:15.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/tools.cpp 2004-01-24 09:20:56.000000000 +0100
@@ -613,7 +613,7 @@
}
GtkWidget *
-gnomemeeting_history_window_new ()
+gnomemeeting_log_window_new ()
{
GtkWidget *window = NULL;
GtkWidget *scr = NULL;
@@ -628,24 +628,24 @@
window = gtk_dialog_new ();
gtk_dialog_add_button (GTK_DIALOG (window), GTK_STOCK_CLOSE, 0);
g_object_set_data_full (G_OBJECT (window), "window_name",
- g_strdup ("general_history_window"), g_free);
+ g_strdup ("log_window"), g_free);
gtk_window_set_title (GTK_WINDOW (window), _("General History"));
gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
- gw->history_text_view = gtk_text_view_new ();
- gtk_text_view_set_editable (GTK_TEXT_VIEW (gw->history_text_view),
+ gw->log_text_view = gtk_text_view_new ();
+ gtk_text_view_set_editable (GTK_TEXT_VIEW (gw->log_text_view),
FALSE);
- gtk_text_view_set_editable (GTK_TEXT_VIEW (gw->history_text_view),
+ gtk_text_view_set_editable (GTK_TEXT_VIEW (gw->log_text_view),
FALSE);
- gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (gw->history_text_view),
+ gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (gw->log_text_view),
GTK_WRAP_WORD);
- gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (gw->history_text_view),
+ gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (gw->log_text_view),
FALSE);
buffer =
- gtk_text_view_get_buffer (GTK_TEXT_VIEW (gw->history_text_view));
+ gtk_text_view_get_buffer (GTK_TEXT_VIEW (gw->log_text_view));
gtk_text_buffer_get_end_iter (buffer, &end);
mark = gtk_text_buffer_create_mark (GTK_TEXT_BUFFER (buffer),
"current-position", &end, FALSE);
@@ -657,7 +657,7 @@
GTK_POLICY_AUTOMATIC,
GTK_POLICY_ALWAYS);
- gtk_container_add (GTK_CONTAINER (scr), gw->history_text_view);
+ gtk_container_add (GTK_CONTAINER (scr), gw->log_text_view);
gtk_box_pack_start (GTK_BOX (GTK_DIALOG (window)->vbox), scr,
TRUE, TRUE, 0);
@@ -683,7 +683,7 @@
va_list args;
GmWindow *gw = GnomeMeeting::Process ()->GetMainWindow ();
- GtkWidget *text_view = gw->history_text_view;
+ GtkWidget *text_view = gw->log_text_view;
GtkTextIter end;
GtkTextMark *mark;
GtkTextBuffer *buffer;
@@ -724,4 +724,3 @@
free (time_str);
delete (timeptr);
}
-
diff -ur gnomemeeting-cvs-20040124.CVS/src/tools.h gnomemeeting-cvs-20040124.CVS.patched/src/tools.h
--- gnomemeeting-cvs-20040124.CVS/src/tools.h 2004-01-22 21:06:25.000000000 +0100
+++ gnomemeeting-cvs-20040124.CVS.patched/src/tools.h 2004-01-24 09:15:44.000000000 +0100
@@ -77,10 +77,10 @@
const char *);
/* DESCRIPTION : /
* BEHAVIOR : Build the history window and returns it.
* PRE : /
*/
-GtkWidget *gnomemeeting_history_window_new ();
+GtkWidget *gnomemeeting_log_window_new ();
/* DESCRIPTION : /
[
Date Prev][
@@ -77,10 +77,10 @@
const char *);
/* DESCRIPTION : /
- * BEHAVIOR : Build the history window and returns it.
+ * BEHAVIOR : Build the log window and returns it.
* PRE : /
*/
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]